==> cfg_e5_2_22_w5_2_46.tar: cfg_e/js/js/tabs/rele_pk4.js <==
function pk4_render_rele() {
    THIS_DEVICE.rele.sort(compareSect);
    let str = '<table class="w3-table w3-table-all">';
    str += '<tr style="background-color: #2196f3">';
    str += '<td>№</td>'
    str += '<td>Тип реле</td>'
    // str += '<td>Ошибка</td>'
    str += '<td>Время работы(сек.)</td>'
    str += '<td>Разделы</td>'
    str += '</tr>';
    let onchangeTime;
    // let rm
    // let alarm = ' привязать к разделу! '
    // for (i in deviceJSON.config) {
    //     if (deviceJSON.config[i].key == 'rm') {
    //         rm = deviceJSON.config[i].subvalues[0].value;
    //         return;
    //     }
    // }
    for (var i = 0; i < THIS_DEVICE.rele.length; i++) {
        THIS_DEVICE.rele[i].inline ? onchangeTime = 'pk4_rele_time(this)' : onchangeTime = 'pk4_rele_time_EXT(this)';
        str += '<tr>';
        str += '<td>' + THIS_DEVICE.rele[i].number + '</td>'
        str += '<td>' + pk4_device_type_rele(THIS_DEVICE.rele[i].mode, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].inline) + '</td>'
        str += '<td><input onchange="' + onchangeTime + '" name="' + THIS_DEVICE.rele[i].number + '" style="width:50px" value="' + THIS_DEVICE.rele[i].time + '"></td>'
        // if (rm === '3' || rm === '5') {
        //     str += '<td>' + alarm + '</td>'
        // }

        str += '<td>' + append_rele_pk4(THIS_DEVICE.rele[i].section, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].mode) + '</td>'

        /*  else {
             str += '<td>' + '</td>'
         } */

        str += '</tr>';
    }

    str += '</table>';
    document.getElementById('tab_rele_pk4_table').innerHTML = str;
}

function append_rele_pk4(activeSections, number, mode) {
    // Вывод списка раздела реле
    let onchangeSections;
    let str = '';
    str += `<div class='${mode !== '11' ? 'w3-dropdown-hover' : ''} w3-mobile'>`;
    str += `<button ${mode === '11' ? 'disabled' : ''} class='w3-border w3-border-red w3-btn w3-white'>Разделы</button>`;
    str += "<div class='w3-dropdown-content w3-bar-block w3-dark-grey'>";

    for (var i = 1; i <= THIS_DEVICE.sensors.length; i++) {
        str += "<label class='w3-bar-item w3-button'><input onchange='pk4_rele_section(this)' name='" + number + "' id='_r_s" + i + "' type='checkbox' ";
        if (activeSections.includes(i + "")) {
            str += " checked ";
        }
        str += " > Раздел " + i + "</label>";
    }
    str += "</div></div>";

    return str
}

function pk4_rele_section(data) {
    let ext = false

    const lock = data.parentNode.parentNode.parentNode.parentNode.parentNode.childNodes[1].childNodes[0].value
    if ((data.parentNode.parentNode.parentNode.parentNode.parentNode.childNodes[1].outerHTML).includes('EXT')) {
        ext = true
    }

    // Привязка разделов к реле
    for (var k = 0; k < THIS_DEVICE.rele.length; k++) {
        let znKey = '';

        let count = 0
        for (const iterator of THIS_DEVICE.rele) {
            if (iterator.inline) {
                count++
            }
        }
        if (count <= 1) {
            // В системе 1 РЕЛЕ
            znKey = 'rz';
        } else {
            // В системе БОЛЬШЕ 1 РЕЛЕ
            znKey = 'rz' + data.name;
        }
        ext ? znKey = 'oq' + data.name : ''; // Если меняем раздлы для РР то используем oq

        for (i in deviceJSON.config) {
            if (deviceJSON.config[i].key == znKey) {
                //deviceJSON.config[i].subvalues[0].value = data.value; // Псевдоним                
                if (data.checked) {
                    // Доабвление разделов
                    let arrRz = []
                    let temp = deviceJSON.config[i].subvalues[0].value
                    if (temp) {
                        arrRz = temp.split(',');
                    }

                    let newValue = ''

                    if (lock === '10') {  // если тип реле Замок
                        newValue = data.id.slice(4)

                    } else {
                        arrRz.push(data.id.slice(4));
                        newValue = arrRz.join(',');
                    }

                    deviceJSON.config[i].subvalues[0].value = newValue;
                    saveConfig(deviceJSON.config[i]);
                    if (lock === '10') {
                        parseAppKey("update_notabs")
                    }
                    return
                } else {
                    // Удаление разделов                    
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    for (var z = 0; z < arrRz.length; z++) {
                        if (+arrRz[z] === +data.id.slice(4)) {
                            arrRz.splice(z, 1); // удаляем элемент
                            let newValue = arrRz.join(',');
                            deviceJSON.config[i].subvalues[0].value = newValue;
                            saveConfig(deviceJSON.config[i]);
                            return
                        }
                    }
                }
            }
        }
    }
}

function pk4_rele_time(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    let count = 0
    for (const iterator of THIS_DEVICE.rele) {
        if (iterator.inline) {
            count++
        }
    }

    if (count <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_rele_time_EXT(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_device_type_rele(value, number, inline) {
    // Отображене типов реле
    // inline - встроенное реле
    let onchangeTyperele;
    inline ? onchangeTyperele = 'pk4_device_set_type_rele(this)' : onchangeTyperele = 'pk4_device_set_type_rele_EXT(this)'
    let str = '';

    str += '<select onchange="' + onchangeTyperele + '" name="' + number + '">';
    if (DEVICEMODEL.charAt(1) === '1' || DEVICEMODEL.slice(-4) === '2022') {
        // ППКОП
        str += '<option style="" value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightcoral" value="6" ';
        if (value === '6') str += ' selected ';
        str += '>ПЦН - Пожар</option>';
        str += '<option style="background:lightcoral" value="7" ';
        if (value === '7') str += ' selected ';
        str += '>Транспарант - Пожар</option>';
        str += '<option style="background:lightcoral" value="8" ';
        if (value === '8') str += ' selected ';
        str += '>Сирена 1 - Пожар</option>';
        str += '<option style="background:lightcoral" value="9" ';
        if (value === '9') str += ' selected ';
        str += '>Сирена 2 - Пожар</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
        str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';

        if (DEVICEMODEL.charAt(1) === '1') {
            str += '<option style="background:lightcoral" value="14" ';
            if (value === '14') str += ' selected ';
            str += '>АСУПТ</option>';
        }

    } else if (DEVICEMODEL.charAt(1) === '2') {
        // ОО
        str += '<option value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
        str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';

    }

    str += '</select>';

    return str
}

function pk4_device_set_type_rele(data) {
    // Смена типа реле
    let rmKey = '';

    let count = 0
    for (const iterator of THIS_DEVICE.rele) {
        if (iterator.inline) {
            count++
        }
    }

    if (count <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
    pk4_render_rele()

}

function pk4_device_set_type_rele_EXT(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}

==> cfg_e5_2_30_w5_2_71.tar: cfg_e/js/js/tabs/rele_pk4.js <==
function pk4_render_rele() {
    if (!paramsReleBrTb) {
        pk4_render_rele_TA()
        return
    }
    THIS_DEVICE.rele.sort(compareSect);
    let str = '<table class="w3-table w3-table-all">';
    str += '<tr style="background-color: #2196f3">';
    str += '<td>№</td>'
    str += '<td>Режим работы</td>'
    // str += '<td>Ошибка</td>'
    str += '<td>Время работы</td>'
    str += '<td>Разделы</td>'
    str += '</tr>';
    let onchangeTime;
    // let rm
    // let alarm = ' привязать к разделу! '
    // for (i in deviceJSON.config) {
    //     if (deviceJSON.config[i].key == 'rm') {
    //         rm = deviceJSON.config[i].subvalues[0].value;
    //         return;
    //     }
    // }
    for (var i = 0; i < THIS_DEVICE.rele.length; i++) {
        THIS_DEVICE.rele[i].inline ? onchangeTime = 'pk4_rele_time(this)' : onchangeTime = 'pk4_rele_time_EXT(this)';
        str += '<tr>';
        str += '<td>' + THIS_DEVICE.rele[i].number + '</td>'
        str += '<td>' + pk4_device_type_rele(THIS_DEVICE.rele[i].mode, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].inline) + '</td>'
        str += '<td><input onchange="' + onchangeTime + '" name="' + THIS_DEVICE.rele[i].number + '" style="width:50px" value="' + THIS_DEVICE.rele[i].time + '"> Сек.</td>'
        // if (rm === '3' || rm === '5') {
        //     str += '<td>' + alarm + '</td>'
        // }

        str += '<td>' + append_rele_pk4(THIS_DEVICE.rele[i].section, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].mode) + '</td>'

        /*  else {
             str += '<td>' + '</td>'
         } */

        str += '</tr>';
    }

    str += '</table>';
    document.getElementById('tab_rele_pk4_table').innerHTML = str;
}
function pk4_render_rele_TA() {
    let str = '<table class="w3-table w3-table-all">';
    str += '<tr style="background-color: #2196f3">';
    str += "<td style='cursor:help' title='№ - Номер ВУ ( Р - номер расширителя, ВУ - номер выхода управления расширителя )'>№(Р-ВУ)</td>";
    str += '<td>Режим работы</td>'
    // str += '<td>Ошибка</td>'
    str += '<td>Время работы</td>'
    str += "<td style='cursor:help' title='Список событий при которых включается ОК'>Сработка при</td>";
    str += '<td>Разделы</td>'
    str += '</tr>';
    for (i in key_TA) {
        if (key_TA[i].outputType === "1") {
            str += '<tr name=' + i + '>';
            str += '<td>' + i + '</td>'
            str += '<td>' + listTypeOk(key_TA[i].type, "TF") + '</td>'
            str += '<td><input oninput="setOC_CONTROL_DELAYchange(this, `tf`)" name="' + i + '" style="width:50px" value="' + key_TA[i].delay + '"> Сек.</td>'
            str += "<td>";
            str +=
                "<div style='position: inherit;'  class='w3-mobile w3-dropdown-hover'>" +
                "<button  name='" +
                i +
                "' class='w3-border w3-border-blue w3-btn w3-white'>События</button>" +
                "<div id='box_event_S_" +
                i +
                "' class='w3-dropdown-content w3-bar-block w3-dark-grey'>";
            str +=
                "<label class='w3-bar-item-sm w3-button w3-blue'>"
            str += `События №  ${i}  </label>`
            str +=
                "<button class='w3-bar-item w3-button'><label><input class='w3-check' disabled type='checkbox' checked > Тревоге </label></button>";
            str += "<button style='display:";
            if (key_TA[i].type == "3" || key_TA[i].type == "11" || key_TA[i].type == "10") {
                str += "block";
            } else {
                str += "none";
            }
            str +=
                "' id='armDisarm_exe_" +
                i +
                "' class='w3-bar-item w3-button'><label><input class='w3-check' disabled type='checkbox' checked > Взятии/снятии </label></button>";
            str +=
                "<button class='w3-bar-item w3-button'><label><input class='w3-check' onchange='setTA_CONTROL_DEVICEchange(this,2)' name='ta' type='checkbox' ";
            if (key_TA[i].ktc == "1") {
                str += " checked ";
            }
            str += " >  КТС </label></button>";

            str +=
                "<button class='w3-bar-item w3-button'><label><input class='w3-check' onchange='setTA_CONTROL_DEVICEchange(this,3)' name='ta' type='checkbox' ";
            if (key_TA[i].hack == "1") {
                str += " checked ";
            }
            str += " > Взлом </label></button>";
            str +=
                "<button class='w3-bar-item w3-button'><label><input class='w3-check' onchange='setTA_CONTROL_DEVICEchange(this,0)' name='ta' type='checkbox' ";
            if (key_TA[i].inversion == "1") {
                str += " checked ";
            }
            str += " > Инвертирование </label></button>";
            str +=
                "<button class='w3-bar-item w3-button'><label><input class='w3-check' onchange='setTA_CONTROL_DEVICEchange(this,1)' name='ta' type='checkbox' ";
            if (key_TA[i].problem == "1") {
                str += " checked ";
            }
            str += " > Неисправность </label></button>";

            /* 
                        str +=
                            "<button class='w3-block' onclick='hideSuNumerEvent_S(this)'  name='" + i + "' ><b>х ЗАКРЫТЬ </b> </button> "; */

            str += "</td>";

            str += '<td>' + append_rele_pk4_TA(key_TA[i].sections, i, key_TA[i].type) + '</td>'

            str += '</tr>';
        }

    }

    str += '</table>';
    document.getElementById('tab_rele_pk4_table').innerHTML = str;
}
function append_rele_pk4_TA(activeSections, number, mode) {
    // Вывод списка раздела реле
    let str = '';
    str += `<div style='position: inherit;' class='${mode !== '11' ? 'w3-dropdown-hover' : ''} w3-mobile '>`;
    str += `<button ${mode === '11' ? 'disabled' : ''} class='w3-border w3-border-red w3-btn w3-white'>Разделы</button>`;
    str += "<div style='height: 400px; overflow-y:scroll; margin-bottom:50px' class='w3-dropdown-content w3-bar-block w3-dark-grey'>";
    for (var r = 1; r <= DEVICEINFO[DEVICEMODEL].sections; r++) {
        str +=
            "<button class='w3-bar-item w3-button'><label><input onchange='setOC_CONTROL_SECTIONSchange(this, `tz`)' name='" +
            r +
            "' type='checkbox' ";
        if (activeSections.includes(r + "")) {
            str += " checked ";
        }
        str += " > Раздел " + r + "</label></button>";
    }

    str += "</div>" + "</div>";

    return str
}

function append_rele_pk4(activeSections, number, mode) {
    // Вывод списка раздела реле
    let onchangeSections;
    let str = '';
    str += `<div class='${mode !== '11' ? 'w3-dropdown-hover' : ''} w3-mobile'>`;
    str += `<button ${mode === '11' ? 'disabled' : ''} class='w3-border w3-border-red w3-btn w3-white'>Разделы</button>`;
    str += "<div class='w3-dropdown-content w3-bar-block w3-dark-grey'>";

    for (var i = 1; i <= DEVICEINFO[DEVICEMODEL].sections; i++) {
        str += "<label class='w3-bar-item w3-button'><input onchange='pk4_rele_section(this)' name='" + number + "' id='_r_s" + i + "' type='checkbox' ";
        if (activeSections.includes(i + "")) {
            str += " checked ";
        }
        str += " > Раздел " + i + "</label>";
    }
    str += "</div></div>";

    return str
}

function pk4_rele_section(data) {
    let ext = false

    const lock = data.parentNode.parentNode.parentNode.parentNode.parentNode.childNodes[1].childNodes[0].value
    if ((data.parentNode.parentNode.parentNode.parentNode.parentNode.childNodes[1].outerHTML).includes('EXT')) {
        ext = true
    }

    // Привязка разделов к реле
    for (var k = 0; k < THIS_DEVICE.rele.length; k++) {
        let znKey = '';

        let count = 0
        for (const iterator of THIS_DEVICE.rele) {
            if (iterator.inline) {
                count++
            }
        }
        if (count <= 1) {
            // В системе 1 РЕЛЕ
            znKey = 'rz';
        } else {
            // В системе БОЛЬШЕ 1 РЕЛЕ
            znKey = 'rz' + data.name;
        }
        ext ? znKey = 'oq' + data.name : ''; // Если меняем раздлы для РР то используем oq

        for (i in deviceJSON.config) {
            if (deviceJSON.config[i].key == znKey) {
                //deviceJSON.config[i].subvalues[0].value = data.value; // Псевдоним                
                if (data.checked) {
                    // Доабвление разделов
                    let arrRz = []
                    let temp = deviceJSON.config[i].subvalues[0].value
                    if (temp) {
                        arrRz = temp.split(',');
                    }

                    let newValue = ''

                    if (lock === '10') {  // если тип реле Замок
                        newValue = data.id.slice(4)

                    } else {
                        arrRz.push(data.id.slice(4));
                        newValue = arrRz.join(',');
                    }

                    deviceJSON.config[i].subvalues[0].value = newValue;
                    saveConfig(deviceJSON.config[i]);
                    if (lock === '10') {
                        parseAppKey("update_notabs")
                    }
                    return
                } else {
                    // Удаление разделов                    
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    for (var z = 0; z < arrRz.length; z++) {
                        if (+arrRz[z] === +data.id.slice(4)) {
                            arrRz.splice(z, 1); // удаляем элемент
                            let newValue = arrRz.join(',');
                            deviceJSON.config[i].subvalues[0].value = newValue;
                            saveConfig(deviceJSON.config[i]);
                            return
                        }
                    }
                }
            }
        }
    }
}

function pk4_rele_time(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    let count = 0
    for (const iterator of THIS_DEVICE.rele) {
        if (iterator.inline) {
            count++
        }
    }

    if (count <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_rele_time_EXT(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_device_type_rele(value, number, inline) {
    // Отображене типов реле
    // inline - встроенное реле
    let onchangeTyperele;
    inline ? onchangeTyperele = 'pk4_device_set_type_rele(this)' : onchangeTyperele = 'pk4_device_set_type_rele_EXT(this)'
    let str = '';

    str += '<select onchange="' + onchangeTyperele + '" name="' + number + '">';
    if (DEVICEMODEL.charAt(1) === '1' || DEVICEMODEL.slice(-4) === '2022') {
        // ППКОП
        str += '<option style="" value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightcoral" value="6" ';
        if (value === '6') str += ' selected ';
        str += '>ПЦН - Пожар</option>';
        str += '<option style="background:lightcoral" value="7" ';
        if (value === '7') str += ' selected ';
        str += '>Транспарант - Пожар</option>';
        str += '<option style="background:lightcoral" value="8" ';
        if (value === '8') str += ' selected ';
        str += '>Сирена 1 - Пожар</option>';
        str += '<option style="background:lightcoral" value="9" ';
        if (value === '9') str += ' selected ';
        str += '>Сирена 2 - Пожар</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
        str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';

        if (DEVICEMODEL.charAt(1) === '1') {
            str += '<option style="background:lightcoral" value="14" ';
            if (value === '14') str += ' selected ';
            str += '>АСУПТ</option>';
        }

    } else if (DEVICEMODEL.charAt(1) === '2') {
        // ОО
        str += '<option value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
        str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';

    }

    str += '</select>';

    return str
}

function pk4_device_set_type_rele(data) {
    // Смена типа реле
    let rmKey = '';

    let count = 0
    for (const iterator of THIS_DEVICE.rele) {
        if (iterator.inline) {
            count++
        }
    }

    if (count <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
    pk4_render_rele()

}

function pk4_device_set_type_rele_EXT(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}
